---
title: ChemMatData
---

# ChemMatData

<p align="center">
    <img src="assets/banner.png" alt="ChemMatData Banner" style="width:80%;">
</p>

The ``chem_mat_data`` package provides easy access to a large range of property prediction datasets from Chemistry and Material Science. 
The aim of this package is to provide the datasets in a unified format suitable to *machine learning* applications and specifically to train 
*graph neural networks (GNNs)*.

Specifically, ``chem_mat_data`` addresses these aims by providing simple, single-line command line (CLI) and programming (API) interfaces to download 
datasets either in *raw* or in *processed* (graph) format.

Features:

- 🐍 Easily installable via ``pip``
- 📦 Instant access to a collection of datasets across the domains of *chemistry* and *material science* 
- 🤖 Direct support of popular graph deep learning libraries like [Torch/PyG](https://pytorch-geometric.readthedocs.io/en/latest/) and [Jax/Jraph](https://jraph.readthedocs.io/en/latest/)
- 🤝 Large python version compatibility
- ⌨️ Comprehensive command line interface (CLI)